"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;

var _babelPluginMacros = require("babel-plugin-macros");

var _path = _interopRequireDefault(require("path"));

var _fs = _interopRequireDefault(require("fs"));

var _hastUtilSelect = _interopRequireDefault(require("hast-util-select"));

var _unified = _interopRequireDefault(require("unified"));

var _rehypeParse = _interopRequireDefault(require("rehype-parse"));

var _svgPathBounds = _interopRequireDefault(require("svg-path-bounds"));

var _normalizeSvgCoords = _interopRequireDefault(require("normalize-svg-coords"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function createFaIcon(source, props) {
  const ast = (0, _unified.default)().use(_rehypeParse.default).data('settings', {
    fragment: true
  }).parse(source);
  const allPaths = (0, _normalizeSvgCoords.default)({
    min: 0,
    max: 256,
    path: _hastUtilSelect.default.selectAll('path', ast).map(p => p.properties.d).filter(Boolean).join('')
  });
  const [,, width, height] = (0, _svgPathBounds.default)(allPaths);
  return Object.assign({}, {
    prefix: 'far',
    icon: [Math.round(width), Math.round(height), [], null, allPaths]
  }, props);
}

var _default = (0, _babelPluginMacros.createMacro)(faIconMacro);

exports.default = _default;

function faIconMacro({
  references,
  state,
  babel: {
    types: t
  }
}) {
  const {
    default: defaultImport = []
  } = references;
  defaultImport.forEach(referencePath => {
    if (referencePath.parentPath.type === 'CallExpression') {
      if (referencePath === referencePath.parentPath.get('callee')) {
        if (!t.isStringLiteral(referencePath.parentPath.get('arguments.0').node)) {
          throw new _babelPluginMacros.MacroError('`fa-icon.macro` requires a filename to import');
        }

        const filename = _path.default.resolve(_path.default.dirname(state.filename), referencePath.parentPath.get('arguments.0').node.value);

        const svgContents = _fs.default.readFileSync(filename, {
          encoding: 'utf-8'
        });

        referencePath.parentPath.replaceWithSourceString(JSON.stringify(createFaIcon(svgContents, {}), null, 2));
      }

      return;
    }

    throw new _babelPluginMacros.MacroError('`fa-icon.macro` can only be used as a function call. Please refer to fa-icon.macro docs');
  });
}